pub(crate) struct Linkifier<'a> {
inner: &'a mut String,
mentions: MentionsMode<'a>,
}Expand description
A helper type to linkify text.
Fields
inner: &'a mut StringThe string containing the result.
mentions: MentionsMode<'a>The mentions detection setting and results.
Implementations
Sourceimpl<'a> Linkifier<'a>
impl<'a> Linkifier<'a>
Sourcepub(crate) fn new(inner: &'a mut String) -> Self
pub(crate) fn new(inner: &'a mut String) -> Self
Construct a new linkifier that will add text in the given string.
Sourcepub(crate) fn detect_mentions(
self,
room: &'a Room,
pills: &'a mut Vec<Pill>,
detect_at_room: bool,
) -> Self
pub(crate) fn detect_mentions( self, room: &'a Room, pills: &'a mut Vec<Pill>, detect_at_room: bool, ) -> Self
Enable mentions detection in the given room and add pills to the given list.
If detect_at_room is true, it will also try to detect @room
mentions.
Sourcepub(crate) fn linkify(self, text: &str)
pub(crate) fn linkify(self, text: &str)
Search and replace links in the given text.
Returns the list of mentions, if any where found.
Sourcefn append_string(&mut self, s: &str)
fn append_string(&mut self, s: &str)
Append the given string.
Escapes the markup of the string.
Sourcefn append_uri(&mut self, uri: &str, content: &str)
fn append_uri(&mut self, uri: &str, content: &str)
Append the given URI with the given link content.